<?php
/**
 * Catch Everest functions and definitions
 *
 * @package Catch Themes
 * @subpackage Catch Everest
 * @since Catch Everest 1.0
 */


if ( ! function_exists( 'catcheverest_content_width' ) ) :
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet.
	 *
	 * Priority 0 to make it available to lower priority callbacks.
	 *
	 * @global int $content_width
	 */
	function catcheverest_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'catcheverest_content_width', 690 );
	}
endif;
add_action( 'after_setup_theme', 'catcheverest_content_width', 0 );


if ( ! function_exists( 'catcheverest_template_redirect' ) ) :
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet for different value other than the default one
	 *
	 * @global int $content_width
	 */
	function catcheverest_template_redirect() {
	    $layout  = catcheverest_get_theme_layout();

		if ( 'no-sidebar-full-width' == $layout ) {
			$GLOBALS['content_width'] = 1040;
		}
	}
endif;
add_action( 'template_redirect', 'catcheverest_template_redirect' );


if ( ! function_exists( 'catcheverest_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since Catch Everest 1.0
 */
function catcheverest_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on Catch Everest, use a find and replace
	 * to change 'catch-everest-pro' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'catch-everest-pro', get_template_directory() . '/languages' );

	/**
	 * Add callback for custom TinyMCE editor stylesheets. (editor-style.css)
	 * @see http://codex.wordpress.org/Function_Reference/add_editor_style
	 */
	add_editor_style();

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/*
	* Let WordPress manage the document title.
	* By adding theme support, we declare that this theme does not use a
	* hard-coded <title> tag in the document head, and expect WordPress to
	* provide it for us.
	*/
	add_theme_support( 'title-tag' );

	/**
	 * Theme Options Defaults
	 */
	require( get_template_directory() . '/inc/panel/catcheverest-theme-options-defaults.php' );

	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory() . '/inc/catcheverest-functions.php' );

	/**
	 * Metabox
	 */
	require( get_template_directory() . '/inc/catcheverest-metabox.php' );

	/**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );

	/**
	 * Register Sidebar and Widget.
	 */
	require( get_template_directory() . '/inc/catcheverest-widgets.php' );

	/**
	 * About page
	 */
	require( get_template_directory() . '/inc/about.php' );

	/**
	 * EDD Update Support
	 */
	require( get_template_directory() . '/inc/updater/theme-updater.php' );

	/*
	 * This theme supports custom background color and image, and here
	 *
	 */
	add_theme_support( 'custom-background', array( 'wp-head-callback' => 'catcheverest_background_callback' ) );

	register_nav_menus(array(
		'primary' 	=> __( 'Primary Menu', 'catch-everest-pro' ),
		'footer'	=> __( 'Footer Menu', 'catch-everest-pro' )
	) );

	/**
	 * Add support for the Aside Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio' ) );

	/**
     * This feature enables Jetpack plugin Infinite Scroll
     */
    add_theme_support( 'infinite-scroll', array(
		'type'           => 'click',
        'container'      => 'content',
        'footer_widgets' => array( 'sidebar-2', 'sidebar-3', 'sidebar-4' ),
        'footer'         => 'page'
    ) );

	/**
	 * Enable support for Post Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'slider', 1140, 450, true); //Featured Post Slider Image
	add_image_size( 'featured', 690, 462, true); //Featured Image
	add_image_size( 'small-featured', 390, 261, true); //Small Featured Image

	/**
	  * Setup Custom Logo Support for theme
	  * Supported from WordPress version 4.5 onwards
	  * More Info: https://make.wordpress.org/core/2016/03/10/custom-logo/
	  */
	add_theme_support( 'custom-logo',
		array(
			'height'      => 300,
			'width'       => 125,
			'flex-height' => true,
			'flex-width'  => true,
		)
	);

	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );

	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );

	// Add support for editor styles.
	add_theme_support( 'editor-styles' );

	// Add support for responsive embeds.
	add_theme_support( 'responsive-embeds' );

	// Add custom editor font sizes.
	add_theme_support(
		'editor-font-sizes',
		array(
			array(
				'name'      => esc_html__( 'Small', 'catch-everest-pro' ),
				'shortName' => esc_html__( 'S', 'catch-everest-pro' ),
				'size'      => 13,
				'slug'      => 'small',
			),
			array(
				'name'      => esc_html__( 'Normal', 'catch-everest-pro' ),
				'shortName' => esc_html__( 'M', 'catch-everest-pro' ),
				'size'      => 16,
				'slug'      => 'normal',
			),
			array(
				'name'      => esc_html__( 'Large', 'catch-everest-pro' ),
				'shortName' => esc_html__( 'L', 'catch-everest-pro' ),
				'size'      => 24,
				'slug'      => 'large',
			),
			array(
				'name'      => esc_html__( 'Huge', 'catch-everest-pro' ),
				'shortName' => esc_html__( 'XL', 'catch-everest-pro' ),
				'size'      => 30,
				'slug'      => 'huge',
			),
		)
	);

	// Add support for custom color scheme.
	add_theme_support( 'editor-color-palette', array(
		array(
			'name'  => esc_html__( 'White', 'catch-everest-pro' ),
			'slug'  => 'white',
			'color' => '#ffffff',
		),
		array(
			'name'  => esc_html__( 'Black', 'catch-everest-pro' ),
			'slug'  => 'black',
			'color' => '#000000',
		),
		array(
			'name'  => esc_html__( 'Dark Gray', 'catch-everest-pro' ),
			'slug'  => 'dark-gray',
			'color' => '#3a3d41',
		),
		array(
			'name'  => esc_html__( 'Medium Gray', 'catch-everest-pro' ),
			'slug'  => 'medium-gray',
			'color' => '#757575',
		),
		array(
			'name'  => esc_html__( 'Light Gray', 'catch-everest-pro' ),
			'slug'  => 'light-gray',
			'color' => '#eeeeee',
		),
		array(
			'name'  => esc_html__( 'Blue', 'catch-everest-pro' ),
			'slug'  => 'blue',
			'color' => '#0088cc',
		),
	) );

}
endif; // catcheverest_setup
add_action( 'after_setup_theme', 'catcheverest_setup' );


if ( ! function_exists( 'catcheverest_get_theme_layout' ) ) :
	/**
	 * Returns Theme Layout prioritizing the meta box layouts
	 *
	 * @uses  get_options
	 *
	 * @action wp_head
	 *
	 * @since Catch Everest 3.5
	 */
	function catcheverest_get_theme_layout() {
		$id = '';

		global $post, $wp_query;

	    // Front page displays in Reading Settings
		$page_on_front  = get_option('page_on_front') ;
		$page_for_posts = get_option('page_for_posts');

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();

		// Blog Page or Front Page setting in Reading Settings
		if ( $page_id == $page_for_posts || $page_id == $page_on_front ) {
	        $id = $page_id;
	    }
	    elseif ( is_singular() ) {
	 		if ( is_attachment() ) {
				$id = $post->post_parent;
			}
			else {
				$id = $post->ID;
			}
		}

		//Get appropriate metabox value of layout
		if ( '' != $id ) {
			$layout = get_post_meta( $id, 'catcheverest-sidebarlayout', true );
		}
		else {
			$layout = 'default';
		}

		//Load options data
		global $catcheverest_options_settings;
   		$options = $catcheverest_options_settings;

   		//check empty and load default
		if ( empty( $layout ) || 'default' == $layout ) {
			$layout = $options['sidebar_layout'];
		}

		return $layout;
	}
endif; //catcheverest_get_theme_layout


/**
 * Implement the Custom Header feature
 */
require( get_template_directory() . '/inc/custom-header.php' );


function catcheverest_background_callback() {

	/* Get the background image. */
	$image = get_background_image();

	/* If there's an image, just call the normal WordPress callback. We won't do anything here. */
	if ( !empty( $image ) ) {
		_custom_background_cb();
		return;
	}

	/* Get the background color. */
	$color = get_background_color();

	/* If no background color, return. */
	if ( empty( $color ) )
		return;

	/* Use 'background' instead of 'background-color'. */
	$style = "background: #{$color};";

?>
<style type="text/css">body { <?php echo trim( $style ); ?> }</style>
<?php
}

/**
 * Register Customizer
 */
require trailingslashit( get_template_directory() ) . '/inc/panel/customizer/customizer.php';


/**
 * Add Support for WooCommerce Plugin
 */
require trailingslashit( get_template_directory() ) . '/inc/catcheverest-woocommerce.php';


/**
 * Add Support for mqTranslate and qTranslate Plugin
 */
if ( in_array( 'qtranslate/qtranslate.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ||
in_array( 'mqtranslate/mqtranslate.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	require( get_template_directory() . '/inc/catcheverest-qtranslate.php' );
}


/**
 * Add Support for WPML, qTranslate X & Polylang Plugin
 */
if ( defined( 'ICL_SITEPRESS_VERSION' ) || defined( 'QTX_VERSION' ) || class_exists( 'Polylang' ) ) {
	require( get_template_directory() . '/inc/catcheverest-wpml.php' );
}


/**
 * Migrate Logo to New WordPress core Custom Logo
 *
 * Runs if version number saved in theme_mod "logo_version" doesn't match current theme version.
 */
function catcheverest_logo_migrate() {
	$ver = get_theme_mod( 'logo_version', false );

	// Return if update has already been run
	if ( version_compare( $ver, '3.6' ) >= 0 ) {
		return;
	}

	/**
	 * If a logo has been set previously, update to use logo feature introduced in WordPress 4.5
	 * Then, move custom header image to core header image as hereh, header image is being used as a logo
	 */
	if ( function_exists( 'the_custom_logo' ) ) {

		//Step 1: Move header image to logo
		$header_image = get_header_image();

		if ( ! empty( $header_image ) ) {
			// Since previous logo was stored a URL, convert it to an attachment ID
			$logo = attachment_url_to_postid( $header_image );

			if ( is_int( $logo ) ) {
				set_theme_mod( 'custom_logo', $logo );
			}
		}
		//End Step 1

		//Step 2: Move Custom header image url to core header image
		/**
		 * Get Theme Options Values
		 */
		global $catcheverest_options_settings;
	   	$options = $catcheverest_options_settings;

		if ( isset( $options['featured_header_image'] ) && '' != $options['featured_header_image'] ) {
			$header_image_id             = attachment_url_to_postid( $options['featured_header_image'] );

			$header_image                = wp_get_attachment_metadata( $header_image_id );

			$header_image_thumbnail_size = wp_get_attachment_image_src( $header_image_id, 'thumbnail' );

			$header_image_data = (object) array(
	            'attachment_id' => $header_image_id,
	            'url'           => $options['featured_header_image'],
	            'thumbnail_url' => isset( $header_image_thumbnail_size[0] ) ? $header_image_thumbnail_size[0] : '',
	            'height'        => $header_image['height'],
	            'width'         => $header_image['width'],
	        );

			set_theme_mod( 'header_image', esc_url_raw( $options['featured_header_image'] ) );

			set_theme_mod( 'header_image_data', $header_image_data );
		}

		//End Step 2

		//Refresh featured header image transient
		delete_transient( 'catcheverest_featured_image' );

  		// Update to match logo_version so that script is not executed continously
		set_theme_mod( 'logo_version', '3.6' );
	}
}
add_action( 'after_setup_theme', 'catcheverest_logo_migrate' );

/**
 * Checks if there are options already present from Catch Everest free version and adds it to the Catch Everest Pro theme options
 *
 * @since Catch Everest Pro 3.5
 * @hook after_theme_switch
 */
function catcheverest_setup_options( $old_theme_name ) {
	if ( $old_theme_name ) {
		$old_theme_slug = sanitize_title( $old_theme_name );

		$free_version_slug = 'catch-everest';
		$pro_version_slug  = 'catch-everest-pro';

		$free_options = get_option( 'theme_mods_' . $old_theme_slug );

		// Perform action only if options of free version exists and theme is being switched from free version
		if ( $free_version_slug === $old_theme_slug && $free_options && '1' !== get_theme_mod( 'free_pro_migration' ) ) {
			$new_options = wp_parse_args( get_theme_mods(), $free_options );

			if ( update_option( 'theme_mods_' . $pro_version_slug, $free_options ) ) {
				// Set Migration Parameter to true so that this script does not run multiple times.
				set_theme_mod( 'free_pro_migration', '1' );
			}
		}
	}
}
add_action( 'after_switch_theme', 'catcheverest_setup_options', 100 );
